/*
 * Copyright  2008 Nokia Corporation.
 */

#ifndef __MOBILEPAINTAPPVIEW_h__
#define __MOBILEPAINTAPPVIEW_h__

// INCLUDES
#include <coecntrl.h>
#include <BitmapTransforms.h>
#include <e32base.h>
#include <AknToolbarObserver.h>

class CDrawingEngine;
class CToolbarControl;
class CMobilePaintAppUi;

class MBitmapRotatorObserver
    {
    public:
        virtual void RotationCompletedL(TInt aError)=0;
    };

class CBitmapRotatorAO : public CActive
    {
    public:
        static CBitmapRotatorAO* NewL(MBitmapRotatorObserver* aObserver);
        static CBitmapRotatorAO* NewLC(MBitmapRotatorObserver* aObserver);
        virtual ~CBitmapRotatorAO();

    public:
        void Rotate(CBitmapRotator::TRotationAngle aAngle, CFbsBitmap* aTarget);
        void DoCancel();
        void RunL();
        TInt RunError(TInt aError);
        
    private:
        void ConstructL();
        CBitmapRotatorAO(MBitmapRotatorObserver* aObserver);
    
    private:
        MBitmapRotatorObserver* iObserver;
        CBitmapRotator*         iBitmapRotator;
    };


// CLASS DECLARATION
class CMobilePaintAppView : public CCoeControl
, public MBitmapRotatorObserver, public MAknToolbarObserver
    {
    enum TControlState
        {
        EIdle = 0,
        EPointerOnToolbar
        };
    

    public:
        static CMobilePaintAppView* NewL (const TRect& aRect );
        static CMobilePaintAppView* NewLC (const TRect& aRect );
        virtual ~CMobilePaintAppView ( );

    public:
        void Draw (const TRect& aRect ) const;
        void DrawCbaButtons(CWindowGc& aGc) const;
        void SizeChanged ( );
        void HandleResourceChange(TInt aType);
        inline CFbsBitmap* BackBuffer(){return iBackBuffer;};
        inline CFbsBitGc* BackBufferContext(){return iBackBufferContext;};
        inline CDrawingEngine* DrawingEngine(){return iDrawingEngine;};
        void NewPictureL();

        void RestoreBackBufferL();
        
    private:
        void ConstructL (const TRect& aRect );
        CMobilePaintAppView ( );
        void HandlePointerEventL(const TPointerEvent& aPointerEvent);

        void CreateBackBufferL();
        void ReleaseBackBuffer();
        void CopyBackBufferL();
        

        void ClearBackground();

        void RotateBackBufferL();
        TInt DataStride(const CFbsBitmap* aBitmap);

    private: // From MBitmapRotatorObserver
        void RotationCompletedL(TInt aError);
        
    private: // From MAknToolbarObserver
        void OfferToolbarEventL(TInt aCommand);
        
private:
    TPoint iPoint;
    TPoint iPoint2;
    TBool  iLineReady;
    TBool  iClearScreen;

    CDrawingEngine*                 iDrawingEngine;
    CToolbarControl*                iCustomToolbarControl;
    CAknToolbar*                    iAknToolbar;
    
    // double buffer bitmapsystem
    CFbsBitmap*                     iBackBuffer;
    CFbsBitmap*                     iCopyOfBackBuffer;
    CFbsBitmapDevice*               iBackBufferDevice;
    CFbsBitmapDevice*               iCopyBackBufferDevice;
    CFbsBitGc*                      iBackBufferContext;
    TSize                           iBackBufferSize;
    
    TControlState                   iControlState;
    
    TPointerEvent                   iPointerEvent;
    
    TRect                           iAcceptDrawingRect;
    
    CBitmapRotatorAO*               iBackBufferRotator;
    TBool                           iBitmapRotationRunning;
    
    CMobilePaintAppUi*              iAppUi;
    TRect                           iCbaBackground;
    TRect                           iOptionCBA;
    TRect                           iExitCBA;
    };

#endif // __MOBILEPAINTAPPVIEW_h__
// End of File
