/*
 * Copyright  2008 Nokia Corporation.
 */

// INCLUDE FILES
#include "csplashscreendialog.h"
#include "MobilePaintAppUi.h"
#include "csvghandler.h"

const TInt KShowTime(2000000);

CSplashScreenDialog::CSplashScreenDialog()
    {
    iAppUi = (static_cast<CMobilePaintAppUi*>(iEikonEnv->AppUi()));
    
    // Closes this dialog after KShowTime 2s
    TRAPD(err,
            iPeriodic = CPeriodic::NewL(CActive::EPriorityIdle);
    );
    if (!err)
        {
        iPeriodic->Start(KShowTime, KShowTime, TCallBack(HideDialog, this));
        }
    }

CSplashScreenDialog::~CSplashScreenDialog()
    {
    if (iPeriodic)
        {
        iPeriodic->Cancel();
        }
    delete iPeriodic;
    }

void CSplashScreenDialog::PreLayoutDynInitL()
    {
    CAknQueryDialog::PreLayoutDynInitL();
    SetEditableL(EFalse);    
    }

void CSplashScreenDialog::PostLayoutDynInitL()
    {
    // No CBA buttons
    CEikButtonGroupContainer* cba = CEikButtonGroupContainer::Current();
    cba->MakeVisible(EFalse);

    // Calculate position of the dialog
    CalculatePositionAndSize();
    }

TBool CSplashScreenDialog::OkToExitL(TInt /*aButtonId*/)
    {
    return ETrue;
    }

TInt CSplashScreenDialog::CountComponentControls() const
    {
    return( 0 ); 
    }

CCoeControl* CSplashScreenDialog::ComponentControl(TInt /*aIndex*/) const
    {
    return NULL;
    }

void CSplashScreenDialog::CalculatePositionAndSize()
    {
    // Set full screen
    SetExtentToWholeScreen();
    }

void CSplashScreenDialog::SetSizeAndPosition(const TSize &aSize)
    {
    CAknQueryDialog::SetSizeAndPosition( aSize );
    CalculatePositionAndSize();
    }

void CSplashScreenDialog::SizeChanged()
    {
    DrawNow();
    }

void CSplashScreenDialog::HandleResourceChange(TInt aType)
    {
    CAknQueryDialog::HandleResourceChange(aType);   
    }

void CSplashScreenDialog::Draw( const TRect& /*aRect*/ ) const
    {
    // Get the standard graphics context
    CWindowGc& gc = SystemGc();

    // Draw picture
    if (iAppUi->CbaPosition()==AknLayoutUtils::EAknCbaLocationBottom)
        {
        gc.BitBlt(Rect().iTl, iAppUi->SvgHandler()->iSplashScreenPortraitBitmap);
        }
    else
        {
        gc.BitBlt(Rect().iTl, iAppUi->SvgHandler()->iSplashScreenLandscapeBitmap);
        }
    }

TInt CSplashScreenDialog::HideDialog(TAny* aAny)
    {
    // Closes dialog
    CSplashScreenDialog* self = static_cast<CSplashScreenDialog*>( aAny );

    self->iPeriodic->Cancel();
    
    TRAP_IGNORE(
            self->TryExitL(1);
            );
    return KErrNone;
    }


